Handsontable - JavaScript data grid editor. Excel-like grid editing with HTML & JavaScript
Description: Excel-like data grid with HTML & JavaScript

Star Fork
This page has been moved to http://handsontable.com/. Please update your bookmarks.

Handsontable is a minimalist Excel-like data grid editor for HTML & JavaScript

This is Handsontable , a release published on April 7th, 2015.

The most prominent changes are:

- modified fixed header/overlay structure - each overlay has its own hidden scrollbar - change was made to reduce the laggy overlay effect for IE and Safari,
  Please note: In order to maintain the pre-0.14.0 scrollbar functionality, change the CSS `overflow` property of your Handsontable container from `scroll` or `auto` to `hidden`. Without performing this change, you might encounter problems with doubling scrollbars.
- Adding JSDoc to the project,
- Removal of jQuery UI datepicker - we switched to Pikaday + Moment.js, that makes us jQuery-free

Check out the full release notes. If you experience some rough edges, please report an issue or temporarily stick to version 0.10.5 .
Releases Wiki Options Methods Events F.A.Q. Source Issues